@@ -6,7 +6,6 @@
 #include "abstractapi.h"
 #include "channel.h"
 #include "comment.h"
-#include "credentials.h"
 #include "playlist.h"
 #include "preferences.h"
 #include "searchparameters.h"
@@ -32,26 +31,33 @@ class InvidiousApi : public AbstractApi
 public:
     explicit InvidiousApi(QNetworkAccessManager *netManager, QObject *parent = nullptr);
 
-    QFuture<LogInResult> logIn(QStringView username, QStringView password) override;
-    QFuture<VideoResult> requestVideo(QStringView videoId) override;
-    QString resolveVideoUrl(QStringView videoId) override;
-    QFuture<SearchListResult> requestSearchResults(const SearchParameters &parameters) override;
-    QFuture<VideoListResult> requestFeed(qint32 page = 1) override;
+    bool isLoggedIn() const override;
+    bool canLogIn() const override;
+    void loadCredentials(const QString &prefix) override;
+    void saveCredentials(const QString &prefix) override;
+    void wipeCredentials(const QString &prefix) override;
+
+    QFuture<LogInResult> logIn(const QString &username, const QString &password) override;
+    QFuture<VideoResult> requestVideo(const QString &videoId) override;
+    QString resolveVideoUrl(const QString &videoId) override;
+    QFuture<SearchListResult> requestSearchResults(const SearchParameters &parameters, Paginator *paginator = nullptr) override;
+    QFuture<VideoListResult> requestFeed(Paginator *paginator = nullptr) override;
     QFuture<VideoListResult> requestTop() override;
-    QFuture<VideoListResult> requestTrending(TrendingTopic = Main) override;
-    QFuture<VideoListResult> requestChannel(QStringView query, qint32 page = 1) override;
+    QFuture<VideoListResult> requestTrending(TrendingTopic = Main, Paginator *paginator = nullptr) override;
+    QFuture<VideoListResult> requestChannel(const QString &query, Paginator *paginator = nullptr) override;
     QFuture<SubscriptionsResult> requestSubscriptions() override;
-    QFuture<Result> subscribeToChannel(QStringView channel) override;
-    QFuture<Result> unsubscribeFromChannel(QStringView channel) override;
-    QFuture<HistoryResult> requestHistory(qint32 page = 1) override;
+    QFuture<Result> subscribeToChannel(const QString &channel) override;
+    QFuture<Result> unsubscribeFromChannel(const QString &channel) override;
+    QFuture<HistoryResult> requestHistory(Paginator *paginator = nullptr) override;
     QFuture<Result> markWatched(const QString &videoId) override;
     QFuture<Result> markUnwatched(const QString &videoId) override;
-    QFuture<CommentsResult> requestComments(const QString &videoId, const QString &continuation = {}) override;
+    QFuture<CommentsResult> requestComments(const QString &videoId, Paginator *paginator = nullptr) override;
     QFuture<PlaylistsResult> requestPlaylists() override;
     QFuture<PreferencesResult> requestPreferences() override;
     QFuture<Result> setPreferences(const QInvidious::Preferences &preferences) override;
     QFuture<VideoListResult> requestPlaylist(const QString &plid) override;
-    QFuture<ChannelResult> requestChannelInfo(QStringView queryd) override;
+    QFuture<ChannelResult> requestChannelInfo(const QString &queryd) override;
+    QFuture<PlaylistsResult> requestChannelPlaylists(const QString &channelId) override;
     QFuture<Result> addVideoToPlaylist(const QString &plid, const QString &videoId) override;
     QFuture<Result> removeVideoFromPlaylist(const QString &plid, const QString &indexId) override;
 
@@ -63,13 +69,16 @@ private:
 
     bool supportsFeature(SupportedFeature feature) override;
 
-    QFuture<VideoListResult> requestVideoList(VideoListType queryType, const QString &urlExtension = {}, const QHash<QString, QString> &parameters = {});
+    QFuture<VideoListResult>
+    requestVideoList(VideoListType queryType, const QString &urlExtension = {}, const QHash<QString, QString> &parameters = {}, Paginator *paginator = nullptr);
     QNetworkRequest authenticatedNetworkRequest(QUrl &&url);
     QUrlQuery genericUrlQuery() const;
-    QUrl videoUrl(QStringView videoId) const;
+    QUrl videoUrl(const QString &videoId) const;
     QUrl videoListUrl(VideoListType queryType, const QString &urlExtension = {}, const QHash<QString, QString> &parameters = {}) const;
     QUrl subscriptionsUrl() const;
-    QUrl subscribeUrl(QStringView channelId) const;
+    QUrl subscribeUrl(const QString &channelId) const;
+
+    std::optional<QNetworkCookie> m_cookie;
 };
 
 }
