@@ -13,13 +13,13 @@ VideoBasicInfo VideoBasicInfo::fromJson(const QJsonObject &obj, VideoBasicInfo &
     if (isPeerTube) {
         info.m_videoId = obj.value("uuid"_L1).toString();
         info.m_title = obj.value("name"_L1).toString();
-        info.m_length = QTime(0, 0).addSecs(obj.value("duration"_L1).toInt());
+        info.m_length = obj.value("duration"_L1).toInt();
         info.m_viewCount = obj.value("views"_L1).toInt();
 
         const auto channel = obj.value("channel"_L1).toObject();
 
         info.m_author = channel.value("displayName"_L1).toString();
-        info.m_authorId = channel.value("name"_L1).toString();
+        info.m_authorId = channel.value("name"_L1).toString() + u'@' + channel.value("host"_L1).toString();
         info.m_authorUrl = channel.value("url"_L1).toString();
         info.m_published = QDateTime::fromString(obj.value("createdAt"_L1).toString(), Qt::ISODate);
         info.m_description = obj.value("description"_L1).toString();
@@ -28,19 +28,25 @@ VideoBasicInfo VideoBasicInfo::fromJson(const QJsonObject &obj, VideoBasicInfo &
         info.m_paid = false;
         info.m_premium = false;
         info.m_upcoming = false;
+        info.m_url = obj.value("url"_L1).toString();
 
         VideoThumbnail thumbnail;
-        const auto thumbnailPath = obj.value("thumbnailPath"_L1).toString();
-        if (thumbnailPath.startsWith(u'/')) {
-            thumbnail.setUrl(QUrl(obj.value("thumbnailPath"_L1).toString()));
-        } else {
-            thumbnail.setUrl(QUrl::fromUserInput(thumbnailPath));
+        // If we have a thumbnail URL, prefer that
+        if (obj.contains("thumbnailUrl"_L1)) {
+            thumbnail.setUrl(QUrl::fromUserInput(obj.value("thumbnailUrl"_L1).toString()));
+        } else if (obj.contains("thumbnailPath"_L1)) {
+            const auto thumbnailPath = obj.value("thumbnailPath"_L1).toString();
+            if (thumbnailPath.startsWith(u'/')) {
+                thumbnail.setUrl(QUrl(obj.value("thumbnailPath"_L1).toString()));
+            } else {
+                thumbnail.setUrl(QUrl::fromUserInput(thumbnailPath));
+            }
         }
         info.m_videoThumbnails.push_back(thumbnail);
     } else if (isInvidious) {
         info.m_videoId = obj.value("videoId"_L1).toString();
         info.m_title = obj.value("title"_L1).toString();
-        info.m_length = QTime(0, 0).addSecs(obj.value("lengthSeconds"_L1).toInt());
+        info.m_length = obj.value("lengthSeconds"_L1).toInt();
         info.m_viewCount = obj.value("viewCount"_L1).toInt();
         info.m_author = obj.value("author"_L1).toString();
         info.m_authorId = obj.value("authorId"_L1).toString();
@@ -59,10 +65,11 @@ VideoBasicInfo VideoBasicInfo::fromJson(const QJsonObject &obj, VideoBasicInfo &
         if (obj.contains("indexId"_L1)) {
             info.m_indexId = obj.value("indexId"_L1).toString();
         }
+        info.m_url = QStringLiteral("https://youtube.com/watch?=%1").arg(info.m_videoId);
     } else {
         info.m_videoId = obj.value("url"_L1).toString().remove(QStringLiteral("/watch?v="));
         info.m_title = obj.value("title"_L1).toString();
-        info.m_length = QTime(0, 0).addSecs(obj.value("duration"_L1).toInt());
+        info.m_length = obj.value("duration"_L1).toInt();
         info.m_viewCount = obj.value("views"_L1).toInt();
         info.m_author = obj.value("uploaderName"_L1).toString();
         info.m_authorUrl = obj.value("uploaderUrl"_L1).toString();
@@ -80,6 +87,7 @@ VideoBasicInfo VideoBasicInfo::fromJson(const QJsonObject &obj, VideoBasicInfo &
         info.m_paid = false;
         info.m_premium = false;
         info.m_upcoming = false;
+        info.m_url = QStringLiteral("https://youtube.com%1").arg(obj.value("url"_L1).toString());
 
         VideoThumbnail thumbnail;
         thumbnail.setUrl(QUrl::fromUserInput(obj.value("thumbnail"_L1).toString()));
@@ -125,7 +133,7 @@ VideoThumbnail VideoBasicInfo::thumbnail(const QString &quality) const
     return {};
 }
 
-QTime VideoBasicInfo::length() const
+qint64 VideoBasicInfo::length() const
 {
     return m_length;
 }
@@ -194,3 +202,8 @@ QString VideoBasicInfo::indexId() const
 {
     return m_indexId;
 }
+
+QString VideoBasicInfo::url() const
+{
+    return m_url;
+}
