@@ -1,19 +1,18 @@
 // SPDX-FileCopyrightText: 2023 Joshua Goins <josh@redstrate.com
-//
 // SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "channelcontroller.h"
 
-#include <QFutureWatcher>
+#include "plasmatube.h"
 
-#include "controllers/plasmatube.h"
+#include <QFutureWatcher>
 
 ChannelController::ChannelController(QObject *parent)
     : QObject(parent)
 {
 }
 
-void ChannelController::loadChannel(QString channelId)
+void ChannelController::loadChannel(const QString &channelId)
 {
     m_watcher = new QFutureWatcher<QInvidious::ChannelResult>();
 
